"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const underscore_string_1 = __importDefault(require("underscore.string"));
const moment_1 = __importDefault(require("moment"));
const logemitter = {
    colormap: {
        WARN: chalk_1.default.yellowBright,
        ERROR: chalk_1.default.redBright,
        FATAL: chalk_1.default.redBright,
        INFO: chalk_1.default.greenBright,
        DEBUG: chalk_1.default.cyan
    },
    sort: function (logs) {
        return logs.sort((a, b) => (a.timestamp || moment_1.default('1900-01-01')).valueOf() - (b.timestamp || moment_1.default('1900-01-01')).valueOf());
    },
    output: function (logs, printnots, debug) {
        if (logs.length === 0 && debug) {
            console.log('.');
        }
        for (let j = 0; j < logs.length; j++) {
            let log = logs[j];
            if (!printnots && !log.timestamp) {
                // eslint-disable-next-line no-continue
                continue;
            }
            let message = '';
            if (log.timestamp) {
                message = `${log.timestamp.format('YYYY-MM-DD HH.mm.ss.SSS')} `;
            }
            if (log.level) {
                message += `${underscore_string_1.default.rpad(log.level, 5)} `;
            }
            message += log.message;
            let color = this.colormap[log.level];
            if (color) {
                console.log(color(message));
            }
            else {
                console.log(message);
            }
        }
    }
};
exports.default = logemitter;
